/*
OpenIO SDS meta0v2
Copyright (C) 2014 Worldine, original work as part of Redcurrant
Copyright (C) 2015 OpenIO, modified as part of OpenIO Software Defined Storage

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef OIO_SDS__meta0v2__internals_h
# define OIO_SDS__meta0v2__internals_h 1

# define NAME_MSGNAME_M0_GETALL              "M0_ALL"
# define NAME_MSGNAME_M0_GETONE              "M0_GET"
# define NAME_MSGNAME_M0_RELOAD              "M0_RELOAD"
# define NAME_MSGNAME_M0_RESET               "M0_RESET"
# define NAME_MSGNAME_M0_FORCE               "M0_FORCE"
# define NAME_MSGNAME_M0_GET_META1_INFO      "M0_GETM1INFO"
# define NAME_MSGNAME_M0_DESTROY_META1REF    "M0_DELM1REF"
# define NAME_MSGNAME_M0_DESTROY_META0ZKNODE "M0_DELM0ZKNODE"

#endif /*OIO_SDS__meta0v2__internals_h*/
